# Class mariadbrepo::params

class mariadbrepo::install {

  case $mariadbrepo::os {
    #-------------------------------------------------------------------------
    'opensuse': {
      exec { 'Import MariaDB key':
        command => 'rpm --import https://yum.mariadb.org/RPM-GPG-KEY-MariaDB',
        path    => '/usr/local/bin/:/bin/',
      }
      yumrepo { 'mariadb':
        descr          => 'MariaDB Yum Repo',
        enabled        => true,
        gpgcheck       => true,
        proxy          => $mariadbrepo::proxy_url,
        proxy_username => $mariadbrepo::proxy_user,
        proxy_password => $mariadbrepo::proxy_pass,
        gpgkey         => 'https://yum.mariadb.org/RPM-GPG-KEY-MariaDB',
        baseurl        => "http://yum.mariadb.org/${mariadbrepo::release}/opensuse13-${mariadbrepo::arch}",
      }
    }

    #-------------------------------------------------------------------------
    'fedora': {
      exec { 'Import MariaDB key':
        command => 'rpm --import https://yum.mariadb.org/RPM-GPG-KEY-MariaDB',
        path    => '/usr/local/bin/:/bin/',
      }
      
      yumrepo { 'mariadb':
        descr          => 'MariaDB Yum Repo',
        enabled        => true,
        gpgcheck       => true,
        proxy          => $mariadbrepo::proxy_url,
        proxy_username => $mariadbrepo::proxy_user,
        proxy_password => $mariadbrepo::proxy_pass,
        gpgkey         => 'https://yum.mariadb.org/RPM-GPG-KEY-MariaDB',
        baseurl        => "http://yum.mariadb.org/${mariadbrepo::release}/${mariadbrepo::os}${::operatingsystemrelease}-${mariadbrepo::arch}",
        require        => Exec['Import MariaDB key'],
      }
    }

    #-------------------------------------------------------------------------
    'centos', 'rhel': {
      $_osversion = $::operatingsystemrelease ? {
        /^5\..*$/ => '5',
        /^6\..*$/ => '6',
        /^7\..*$/ => '7',
      }

      exec { 'Import MariaDB key':
        command => 'rpm --import https://yum.mariadb.org/RPM-GPG-KEY-MariaDB',
        path    => '/usr/local/bin/:/bin/',
      }
      
      yumrepo { 'mariadb':
        descr          => 'MariaDB Yum Repo',
        enabled        => true,
        gpgcheck       => true,
        proxy          => $mariadbrepo::proxy_url,
        proxy_username => $mariadbrepo::proxy_user,
        proxy_password => $mariadbrepo::proxy_pass,
        gpgkey         => 'https://yum.mariadb.org/RPM-GPG-KEY-MariaDB',
        baseurl        => "http://yum.mariadb.org/${mariadbrepo::release}/${mariadbrepo::os}${_osversion}-${mariadbrepo::arch}",
        require        => Exec['Import MariaDB key'],
      }
    }

    #-------------------------------------------------------------------------
    'ubuntu', 'debian': {
      if $mariadbrepo::proxy_url != 'absent' {
        apt::source { 'MariaDB':
          comment  => 'http://downloads.mariadb.org/mariadb/repositories/',
          location => "${mariadbrepo::debmirror}/${mariadbrepo::release}/${mariadbrepo::os}",
          release  => $::lsbdistcodename,
          repos    => 'main',
          key      => {
            id     => '199369E5404BD5FC7D2FE43BCBCB082A1BB943DB',
            server => 'keyserver.ubuntu.com',
          },
          include  => {
            'src' => true,
            'deb' => true,
          },
          options  => "http-proxy=\"${mariadbrepo::proxy_user}:${mariadbrepo::proxy_pass}@${mariadbrepo::proxy_url}\"",
        }
      }
      else {
        apt::source { 'MariaDB':
          comment  => 'http://downloads.mariadb.org/mariadb/repositories/',
          location => "${mariadbrepo::debmirror}/${mariadbrepo::release}/${mariadbrepo::os}",
          release  => $::lsbdistcodename,
          repos    => 'main',
          key      => {
            id     => '199369E5404BD5FC7D2FE43BCBCB082A1BB943DB',
            server => 'keyserver.ubuntu.com',
          },
          include  => {
            'src' => true,
            'deb' => true,
          },
        }
      }

      exec { 'apt-update':
        command => '/usr/bin/apt-get update',
      }
    }

    #-------------------------------------------------------------------------
    # Unsupportes OS are filtered at the params class.
    # So this default rule should never be reached.

    default: {}
  }
}
