# Class mariadbrepo::params

class mariadbrepo::params {

  $release = '10.0'
  $proxy_url = 'absent'
  $proxy_user = undef
  $proxy_pass = undef
  $debmirror  = 'http://mirrors.n-ix.net/mariadb/repo/'

  # Some more mirrors (or pick one from https://downloads.mariadb.org/mariadb/repositories/#distro=Debian):

  # Germany
  # http://ftp.hosteurope.de/mirror/mariadb.org/repo/
  # http://mirror.netcologne.de/mariadb/repo/

  # UK
  # http://lon1.mirrors.digitalocean.com/mariadb/repo/

  # USA
  # http://nyc2.mirrors.digitalocean.com/mariadb/repo/
  # http://sfo1.mirrors.digitalocean.com/mariadb/repo/

  
  $os = $::operatingsystem ? {
    'RedHat'    => 'rhel',
    'LinuxMint' => 'ubuntu',
    default     => downcase($::operatingsystem),
  }

  $arch = $::architecture ? {
    /^.*86$/ => 'x86',
    /^.*64$/ => 'amd64',
    default  => fail("Architecture ${::architecture} 
      is not supported by this module."),
  }

  $_os = downcase($::operatingsystem)
  case $_os {
    #-------------------------------------------------------------------------
    'opensuse': {
      case $::operatingsystemrelease {
        /^13\..*/: {
          $allowed_release = ['5.5', '10.0', '10.1' ]

          if ! ($release in $allowed_release) {
            fail("ERROR -> ${::operatingsystem} version 
              ${::operatingsystemrelease} 
              is not supported by MariaDB release ${release}.")
          }
        }
        default: {
          fail("${::operatingsystem} version ${::operatingsystemrelease} 
            is not supported by this module")
        }
      }
    }

    #-------------------------------------------------------------------------
    'fedora': {
      case $::operatingsystemrelease {
        /^22$/: {
          $allowed_release = ['10.0', '10.1' ]

          if ! ($release in $allowed_release) {
            fail("ERROR -> ${::operatingsystem} version 
              ${::operatingsystemrelease} 
              is not supported by MariaDB release ${release}.")
          }
        }
        /^23$/: {
          $allowed_release = ['10.0', '10.1' ]

          if ! ($release in $allowed_release) {
            fail("ERROR -> ${::operatingsystem} version 
              ${::operatingsystemrelease} 
              is not supported by MariaDB release ${release}.")
          }
        }
        default: {
          fail("${::operatingsystem} version ${::operatingsystemrelease} 
            is not supported by this module")
        }
      }
    }

    #-------------------------------------------------------------------------
    'centos': {
      case $::operatingsystemrelease {
        /^5\..*/: {
          $allowed_release = ['5.5', '10.0', '10.1' ]

          if ! ($release in $allowed_release) {
            fail("ERROR -> ${::operatingsystem} version 
              ${::operatingsystemrelease} 
              is not supported by MariaDB release ${release}.")
          }
        }
        /^6\..*/: {
          $allowed_release = ['5.5', '10.0', '10.1' ]

          if ! ($release in $allowed_release) {
            fail("ERROR -> ${::operatingsystem} version 
              ${::operatingsystemrelease} 
              is not supported by MariaDB release ${release}.")
          }
        }
        /^7\..*/: {
          $allowed_release = ['5.5', '10.0', '10.1' ]

          if ! ($release in $allowed_release) {
            fail("ERROR -> ${::operatingsystem} version 
              ${::operatingsystemrelease} 
              is not supported by MariaDB release ${release}.")
          }
        }
        default: {
          fail("${::operatingsystem} version ${::operatingsystemrelease} 
            is not supported by this module")
        }
      }
    }

    #-------------------------------------------------------------------------
    'rhel': {
      case $::operatingsystemrelease {
        /^5\..*/: {
          $allowed_release = ['5.5', '10.0', '10.1' ]

          if ! ($release in $allowed_release) {
            fail("ERROR -> ${::operatingsystem} version 
              ${::operatingsystemrelease} 
              is not supported by MariaDB release ${release}.")
          }
        }
        /^6\..*/: {
          $allowed_release = ['5.5', '10.0', '10.1' ]

          if ! ($release in $allowed_release) {
            fail("ERROR -> ${::operatingsystem} version 
              ${::operatingsystemrelease} 
              is not supported by MariaDB release ${release}.")
          }
        }
        /^7\..*/: {
          $allowed_release = ['5.5', '10.0', '10.1' ]

          if ! ($release in $allowed_release) {
            fail("ERROR -> ${::operatingsystem} version 
              ${::operatingsystemrelease} 
              is not supported by MariaDB release ${release}.")
          }
        }
        default: {
          fail("${::operatingsystem} version ${::operatingsystemrelease} 
            is not supported by this module")
        }
      }
    }

    #-------------------------------------------------------------------------
    'ubuntu': {
      case $::operatingsystemrelease {
        /^12\.04$/: {
          $allowed_release = ['5.5', '10.0', '10.1' ]

          if ! ($release in $allowed_release) {
            fail("ERROR -> ${::operatingsystem} version 
              ${::operatingsystemrelease} 
              is not supported by MariaDB release ${release}.")
          }
        }
        /^14\.04$/: {
          $allowed_release = ['5.5', '10.0', '10.1' ]

          if ! ($release in $allowed_release) {
            fail("ERROR -> ${::operatingsystem} version 
              ${::operatingsystemrelease} 
              is not supported by MariaDB release ${release}.")
          }
        }
        /^15\.04$/: {
          $allowed_release = ['10.0', '10.1' ]

          if ! ($release in $allowed_release) {
            fail("ERROR -> ${::operatingsystem} version 
              ${::operatingsystemrelease} 
              is not supported by MariaDB release ${release}.")
          }
        }
        /^15\.10$/: {
          $allowed_release = ['10.0', '10.1' ]

          if ! ($release in $allowed_release) {
            fail("ERROR -> ${::operatingsystem} version 
              ${::operatingsystemrelease} 
              is not supported by MariaDB release ${release}.")
          }
        }
        default: {
          fail("${::operatingsystem} version ${::operatingsystemrelease} 
            is not supported by this module")
        }
      }
    }

    #-------------------------------------------------------------------------
    'debian': {
      case $::operatingsystemrelease {
        /^6\..*/: {
          $allowed_release = ['5.5', '10.0' ]

          if ! ($release in $allowed_release) {
            fail("ERROR -> ${::operatingsystem} version 
              ${::operatingsystemrelease} 
              is not supported by MariaDB release ${release}.")
          }
        }
        /^7\..*/: {
          $allowed_release = ['5.5', '10.0', '10.1' ]

          if ! ($release in $allowed_release) {
            fail("ERROR -> ${::operatingsystem} version 
              ${::operatingsystemrelease} 
              is not supported by MariaDB release ${release}.")
          }
        }
        /^8\..*/: {
          $allowed_release = ['10.0', '10.1' ]

          if ! ($release in $allowed_release) {
            fail("ERROR -> ${::operatingsystem} version 
              ${::operatingsystemrelease} 
              is not supported by MariaDB release ${release}.")
          }
        }
        default: {
          fail("${::operatingsystem} version ${::operatingsystemrelease} 
            is not supported by this module")
        }
      }
    }

    #-------------------------------------------------------------------------
    'linuxmint': {
      case $::operatingsystemrelease {
        /^13$/: {
          $allowed_release = ['5.5', '10.0', '10.1' ]

          if ! ($release in $allowed_release) {
            fail("ERROR -> ${::operatingsystem} version 
              ${::operatingsystemrelease} 
              is not supported by MariaDB release ${release}.")
          }
        }
        /^17$/: {
          $allowed_release = ['5.5', '10.0', '10.1' ]

          if ! ($release in $allowed_release) {
            fail("ERROR -> ${::operatingsystem} version 
              ${::operatingsystemrelease} 
              is not supported by MariaDB release ${release}.")
          }
        }
        /^17\.1$/: {
          $allowed_release = ['5.5', '10.0', '10.1' ]

          if ! ($release in $allowed_release) {
            fail("ERROR -> ${::operatingsystem} version 
              ${::operatingsystemrelease} 
              is not supported by MariaDB release ${release}.")
          }
        }
        default: {
          fail("${::operatingsystem} version ${::operatingsystemrelease} 
            is not supported by this module")
        }
      }
    }

    #-------------------------------------------------------------------------
    default: {
      fail("Operatingsystem ${::operatingsystem} is not 
        supported by this module.")
    }
  }
}